@@ -1,15 +1,18 @@
 
 
 #define NOLOGATALL
-#include "../source/acbuf.cc"
-#include "../include/sockio.h"
-#include "../include/fileio.h"
+#include "acsyscap.h"
+#include "debug.h"
+#include "acbuf.cc"
+#include "sockio.h"
+#include "fileio.h"
 
 #include <unistd.h>
 #include <sys/select.h>
 #include <signal.h>
 
-namespace acng{
+namespace acng
+{
 namespace cfg
 {
 	int nettimeout=60;
@@ -90,14 +93,14 @@ int main(int argc, char **argv)
 	
 	addr.sun_family=PF_UNIX;
 	strcpy(addr.sun_path, argv[1]);
-	socklen_t adlen = pLen+1+offsetof(struct sockaddr_un, sun_path);
+	socklen_t adlen = pLen + 1 + offsetof(struct sockaddr_un, sun_path);
 	if ( 0!=connect(s, (struct sockaddr*)&addr, adlen))
 	{
 		printf("HTTP/1.1 500 ERROR: Unable to attach to the local daemon: %s\r\n\r\n", strerror(errno));
 		return 5;
 	}
 	
-	int maxfd=1+std::max(in, std::max(out, s));
+	int maxfd = 1 + std::max(in, std::max(out, s));
 
 	while (true)
 	{
@@ -126,25 +129,25 @@ int main(int argc, char **argv)
 		
 		if(FD_ISSET(s, &wfds))
 		{
-			if(bufToD.syswrite(s)<0)
+			if(bufToD.dumpall(s) < 0)
 				return 1;
 		}
 		
 		if(FD_ISSET(out, &wfds))
 		{
-			if(bufFromD.syswrite(out)<0)
+			if(bufFromD.dumpall(out) < 0)
 				return 1;
 		}
 		
 		if(FD_ISSET(s, &rfds))
 		{
-			if(bufFromD.sysread(s)<=0)
+			if(bufFromD.sysread(s) <= 0)
 				goto finished;
 		}
 		
 		if(FD_ISSET(in, &rfds))
 		{
-			if(bufToD.sysread(in)<=0)
+			if(bufToD.sysread(in) <= 0)
 				goto finished;
 		}
 	}
